@@ -134,13 +134,13 @@ class Bolt:
 
         # Carry out Bolt subclass imports locally to avoid circular dependency issues.
         from neo4j.io._bolt3 import Bolt3
-        from neo4j.io._bolt4x0 import Bolt4x0
-        from neo4j.io._bolt4x1 import Bolt4x1
+        from neo4j.io._bolt4 import Bolt4x0, Bolt4x1, Bolt4x2
 
         handlers = {
             Bolt3.PROTOCOL_VERSION: Bolt3,
             Bolt4x0.PROTOCOL_VERSION: Bolt4x0,
             Bolt4x1.PROTOCOL_VERSION: Bolt4x1,
+            Bolt4x2.PROTOCOL_VERSION: Bolt4x2,
         }
 
         if protocol_version is None:
@@ -204,12 +204,16 @@ class Bolt:
             connection = Bolt3(address, s, pool_config.max_connection_lifetime, auth=auth, user_agent=pool_config.user_agent, routing_context=routing_context)
         elif pool_config.protocol_version == (4, 0):
             # Carry out Bolt subclass imports locally to avoid circular dependency issues.
-            from neo4j.io._bolt4x0 import Bolt4x0
+            from neo4j.io._bolt4 import Bolt4x0
             connection = Bolt4x0(address, s, pool_config.max_connection_lifetime, auth=auth, user_agent=pool_config.user_agent, routing_context=routing_context)
         elif pool_config.protocol_version == (4, 1):
             # Carry out Bolt subclass imports locally to avoid circular dependency issues.
-            from neo4j.io._bolt4x1 import Bolt4x1
+            from neo4j.io._bolt4 import Bolt4x1
             connection = Bolt4x1(address, s, pool_config.max_connection_lifetime, auth=auth, user_agent=pool_config.user_agent, routing_context=routing_context)
+        elif pool_config.protocol_version == (4, 2):
+            # Carry out Bolt subclass imports locally to avoid circular dependency issues.
+            from neo4j.io._bolt4 import Bolt4x2
+            connection = Bolt4x2(address, s, pool_config.max_connection_lifetime, auth=auth, user_agent=pool_config.user_agent, routing_context=routing_context)
         else:
             log.debug("[#%04X]  S: <CLOSE>", s.getpeername()[1])
             s.shutdown(SHUT_RDWR)
@@ -673,8 +677,7 @@ class Neo4jPool(IOPool):
 
         # Carry out Bolt subclass imports locally to avoid circular dependency issues.
         from neo4j.io._bolt3 import Bolt3
-        from neo4j.io._bolt4x0 import Bolt4x0
-        from neo4j.io._bolt4x1 import Bolt4x1
+        from neo4j.io._bolt4 import Bolt4x0, Bolt4x1, Bolt4x2
 
         from neo4j.api import (
             SYSTEM_DATABASE,
@@ -1006,7 +1009,7 @@ def _handshake(s, resolved_address):
         # response, the server has closed the connection
         log.debug("[#%04X]  S: <CLOSE>", local_port)
         s.close()
-        raise ServiceUnavailable("Connection to {address} closed without handshake response".format(address=resolved_address))
+        raise BoltHandshakeError("Connection to {address} closed without handshake response".format(address=resolved_address), address=resolved_address, request_data=handshake, response_data=None)
     if data_size != 4:
         # Some garbled data has been received
         log.debug("[#%04X]  S: @*#!", local_port)
